import{c as w,a as i,f as x,s as O}from"./BqgPKE-B.js";import"./zzPCSqzL.js";import{f as q,B as Q,D as R,J as f,F as C,I as N,K as t,t as P,M as _}from"./6mnWt3YZ.js";import{I as V,s as A,e as T,i as U,a as Z,c as X,t as Y}from"./BfTcz1DI.js";import{l as K,s as L,a as ee,i as F,b as te}from"./BJ0MJm0w.js";import{c as ae}from"./LjIT5PsV.js";import{M as se,F as re}from"./Md_0usCS.js";import{C as oe}from"./vpNtFX-q.js";import{C as ne}from"./seHlMjav.js";import{C as ie}from"./BNZK7cgo.js";function ye(l,a){const c=K(a,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const d=[["path",{d:"M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z"}],["path",{d:"m9 12 2 2 4-4"}]];V(l,L({name:"badge-check"},()=>c,{get iconNode(){return d},children:(p,o)=>{var s=w(),n=q(s);A(n,a,"default",{}),i(p,s)},$$slots:{default:!0}}))}function be(l,a){const c=K(a,["children","$$slots","$$events","$$legacy"]);/**
 * @license lucide-svelte v0.469.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const d=[["path",{d:"M2.97 12.92A2 2 0 0 0 2 14.63v3.24a2 2 0 0 0 .97 1.71l3 1.8a2 2 0 0 0 2.06 0L12 19v-5.5l-5-3-4.03 2.42Z"}],["path",{d:"m7 16.5-4.74-2.85"}],["path",{d:"m7 16.5 5-3"}],["path",{d:"M7 16.5v5.17"}],["path",{d:"M12 13.5V19l3.97 2.38a2 2 0 0 0 2.06 0l3-1.8a2 2 0 0 0 .97-1.71v-3.24a2 2 0 0 0-.97-1.71L17 10.5l-5 3Z"}],["path",{d:"m17 16.5-5-3"}],["path",{d:"m17 16.5 4.74-2.85"}],["path",{d:"M17 16.5v5.17"}],["path",{d:"M7.97 4.42A2 2 0 0 0 7 6.13v4.37l5 3 5-3V6.13a2 2 0 0 0-.97-1.71l-3-1.8a2 2 0 0 0-2.06 0l-3 1.8Z"}],["path",{d:"M12 8 7.26 5.15"}],["path",{d:"m12 8 4.74-2.85"}],["path",{d:"M12 13.5V8"}]];V(l,L({name:"boxes"},()=>c,{get iconNode(){return d},children:(p,o)=>{var s=w(),n=q(s);A(n,a,"default",{}),i(p,s)},$$slots:{default:!0}}))}var le=x('<div class="phase-line svelte-11chv7q"></div>'),ce=x('<div class="phase-cell svelte-11chv7q"><!> <div><!></div> <span> </span></div>'),de=x('<div class="phase-bar svelte-11chv7q"></div>');function Me(l,a){Q(a,!0);const c=()=>te(Y,"$t",d),[d,p]=ee(),o=[{key:"clarify",icon:se},{key:"plan",icon:oe},{key:"implement",icon:ne},{key:"tests",icon:re}];function s(r){return r==="complete"?"ok":["in_progress","draft","awaiting_review"].includes(r)?"wip":""}function n(r){return r==="complete"?"var(--gn-bright)":["in_progress","draft","awaiting_review"].includes(r)?"var(--yl)":"var(--bg2)"}var u=de();T(u,21,()=>o,U,(r,g,$)=>{const B=_(()=>a.phases[t(g).key]||"not_started"),h=_(()=>s(t(B))),W=_(()=>$<o.length-1&&a.phases[o[$+1].key]||"not_started"),D=_(()=>t(g).icon);var k=ce(),z=C(k);{var J=e=>{var v=le();P((b,M)=>X(v,`background: linear-gradient(to right, ${b??""}, ${M??""})`),[()=>n(t(B)),()=>n(t(W))]),i(e,v)};F(z,e=>{$<o.length-1&&e(J)})}var m=N(z,2),S=C(m);{var j=e=>{ie(e,{size:13,strokeWidth:2.5})},E=e=>{var v=w(),b=q(v);ae(b,()=>t(D),(M,H)=>{H(M,{size:13,strokeWidth:1.5})}),i(e,v)};F(S,e=>{t(h)==="ok"?e(j):e(E,!1)})}f(m);var y=N(m,2);let I;var G=C(y,!0);f(y),f(k),P(e=>{Z(m,1,`dot ${t(h)??""}`,"svelte-11chv7q"),I=Z(y,1,"phase-lbl svelte-11chv7q",null,I,{"lbl-ok":t(h)==="ok","lbl-wip":t(h)==="wip"}),O(G,e)},[()=>c()("phase."+t(g).key)]),i(r,k)}),f(u),i(l,u),R(),p()}export{ye as B,Me as P,be as a};
